### Normalized app and os name for mobile search related tables

Takes app name and os as input :
Returns a struct of normalized_app_name and normalized_app_name_os based on [discussion provided here](https://mozilla-hub.atlassian.net/browse/RS-805)
